@@ -390,6 +390,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateEKSCluster(self, request):
+        """创建弹性集群
+
+        :param request: Request instance for CreateEKSCluster.
+        :type request: :class:`tencentcloud.tke.v20180525.models.CreateEKSClusterRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.CreateEKSClusterResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateEKSCluster", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateEKSClusterResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreatePrometheusDashboard(self, request):
         """创建grafana监控面板
 
@@ -418,6 +446,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreatePrometheusTemplate(self, request):
+        """创建一个云原生Prometheus模板实例
+
+        :param request: Request instance for CreatePrometheusTemplate.
+        :type request: :class:`tencentcloud.tke.v20180525.models.CreatePrometheusTemplateRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.CreatePrometheusTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreatePrometheusTemplate", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreatePrometheusTemplateResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteCluster(self, request):
         """删除集群(YUNAPI V3版本)
 
@@ -642,6 +698,118 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteEKSCluster(self, request):
+        """删除弹性集群(yunapiv3)
+
+        :param request: Request instance for DeleteEKSCluster.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DeleteEKSClusterRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DeleteEKSClusterResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteEKSCluster", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteEKSClusterResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeletePrometheusTemplate(self, request):
+        """删除一个云原生Promehtheus配置模板
+
+        :param request: Request instance for DeletePrometheusTemplate.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DeletePrometheusTemplateRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DeletePrometheusTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeletePrometheusTemplate", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeletePrometheusTemplateResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeletePrometheusTemplateSync(self, request):
+        """取消模板同步，这将会删除目标中该模板所生产的配置
+
+        :param request: Request instance for DeletePrometheusTemplateSync.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DeletePrometheusTemplateSyncRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DeletePrometheusTemplateSyncResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeletePrometheusTemplateSync", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeletePrometheusTemplateSyncResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeAvailableClusterVersion(self, request):
+        """获取集群可以升级的所有版本
+
+        :param request: Request instance for DescribeAvailableClusterVersion.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribeAvailableClusterVersionRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribeAvailableClusterVersionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAvailableClusterVersion", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAvailableClusterVersionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeClusterAsGroupOption(self, request):
         """集群弹性伸缩配置
 
@@ -978,6 +1146,62 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeEKSClusterCredential(self, request):
+        """获取弹性容器集群的接入认证信息
+
+        :param request: Request instance for DescribeEKSClusterCredential.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribeEKSClusterCredentialRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribeEKSClusterCredentialResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeEKSClusterCredential", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeEKSClusterCredentialResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeEKSClusters(self, request):
+        """查询弹性集群列表
+
+        :param request: Request instance for DescribeEKSClusters.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribeEKSClustersRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribeEKSClustersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeEKSClusters", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeEKSClustersResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeExistedInstances(self, request):
         """查询已经存在的节点，判断是否可以加入集群
 
@@ -1062,6 +1286,174 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribePrometheusAgents(self, request):
+        """获取被关联集群列表
+
+        :param request: Request instance for DescribePrometheusAgents.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribePrometheusAgentsRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribePrometheusAgentsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePrometheusAgents", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePrometheusAgentsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribePrometheusAlertRule(self, request):
+        """获取告警规则列表
+
+        :param request: Request instance for DescribePrometheusAlertRule.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribePrometheusAlertRuleRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribePrometheusAlertRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePrometheusAlertRule", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePrometheusAlertRuleResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribePrometheusOverviews(self, request):
+        """获取实例列表
+
+        :param request: Request instance for DescribePrometheusOverviews.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribePrometheusOverviewsRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribePrometheusOverviewsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePrometheusOverviews", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePrometheusOverviewsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribePrometheusTargets(self, request):
+        """获取targets信息
+
+        :param request: Request instance for DescribePrometheusTargets.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribePrometheusTargetsRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribePrometheusTargetsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePrometheusTargets", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePrometheusTargetsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribePrometheusTemplateSync(self, request):
+        """获取模板同步信息
+
+        :param request: Request instance for DescribePrometheusTemplateSync.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribePrometheusTemplateSyncRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribePrometheusTemplateSyncResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePrometheusTemplateSync", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePrometheusTemplateSyncResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribePrometheusTemplates(self, request):
+        """拉取模板列表，默认模板将总是在最前面
+
+        :param request: Request instance for DescribePrometheusTemplates.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribePrometheusTemplatesRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribePrometheusTemplatesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePrometheusTemplates", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePrometheusTemplatesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRegions(self, request):
         """获取容器服务支持的所有地域
 
@@ -1118,6 +1510,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetUpgradeInstanceProgress(self, request):
+        """获得节点升级当前的进度
+
+        :param request: Request instance for GetUpgradeInstanceProgress.
+        :type request: :class:`tencentcloud.tke.v20180525.models.GetUpgradeInstanceProgressRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.GetUpgradeInstanceProgressResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetUpgradeInstanceProgress", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetUpgradeInstanceProgressResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyClusterAsGroupAttribute(self, request):
         """修改集群伸缩组属性
 
@@ -1146,6 +1566,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyClusterAsGroupOptionAttribute(self, request):
+        """修改集群弹性伸缩属性
+
+        :param request: Request instance for ModifyClusterAsGroupOptionAttribute.
+        :type request: :class:`tencentcloud.tke.v20180525.models.ModifyClusterAsGroupOptionAttributeRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.ModifyClusterAsGroupOptionAttributeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyClusterAsGroupOptionAttribute", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyClusterAsGroupOptionAttributeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyClusterAttribute(self, request):
         """修改集群属性
 
@@ -1230,6 +1678,62 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyNodePoolDesiredCapacityAboutAsg(self, request):
+        """修改节点池关联伸缩组的期望实例数
+
+        :param request: Request instance for ModifyNodePoolDesiredCapacityAboutAsg.
+        :type request: :class:`tencentcloud.tke.v20180525.models.ModifyNodePoolDesiredCapacityAboutAsgRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.ModifyNodePoolDesiredCapacityAboutAsgResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyNodePoolDesiredCapacityAboutAsg", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyNodePoolDesiredCapacityAboutAsgResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifyPrometheusTemplate(self, request):
+        """修改模板内容
+
+        :param request: Request instance for ModifyPrometheusTemplate.
+        :type request: :class:`tencentcloud.tke.v20180525.models.ModifyPrometheusTemplateRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.ModifyPrometheusTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyPrometheusTemplate", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyPrometheusTemplateResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RemoveNodeFromNodePool(self, request):
         """移出节点池节点，但保留在集群内
 
@@ -1258,6 +1762,90 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def SyncPrometheusTemplate(self, request):
+        """同步模板到实例或者集群
+
+        :param request: Request instance for SyncPrometheusTemplate.
+        :type request: :class:`tencentcloud.tke.v20180525.models.SyncPrometheusTemplateRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.SyncPrometheusTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("SyncPrometheusTemplate", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.SyncPrometheusTemplateResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UpdateClusterVersion(self, request):
+        """升级集群 Master 组件到指定版本
+
+        :param request: Request instance for UpdateClusterVersion.
+        :type request: :class:`tencentcloud.tke.v20180525.models.UpdateClusterVersionRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.UpdateClusterVersionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpdateClusterVersion", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateClusterVersionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UpdateEKSCluster(self, request):
+        """修改弹性集群名称等属性
+
+        :param request: Request instance for UpdateEKSCluster.
+        :type request: :class:`tencentcloud.tke.v20180525.models.UpdateEKSClusterRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.UpdateEKSClusterResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpdateEKSCluster", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateEKSClusterResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpgradeClusterInstances(self, request):
         """给集群的一批work节点进行升级
 
